@@ -1,11 +1,9 @@
 import math
 import re
 import signal
-import tempfile
 
 import nltk
 import pandas
-import requests
 from cached_path import cached_path
 from storable import retrieve
 
